==> ejc-bfyjerp-api-3.0.0-20250430.045427-214-sources.jar: com/ejianc/business/oa/vo/MonInsuranceVO.java <==
package com.ejianc.business.oa.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 月度保险明细
 * 
 * @author generator
 * 
 */
public class MonInsuranceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String humanType; // 人员类别
    private String humanTypeName; // 人员类别
    private Long personId; // 姓名
    private String personName; // 姓名
    private Long deptId; // 部门
    private String deptName; // 部门
    private String insuredType; // 保险种类
    private String insuredTypeName; // 保险种类
    private String feesBorne; // 费用承担情况
    private String feesBorneName; // 费用承担情况
    private String year; // 年份
    private String month; // 月度
    private BigDecimal companyTotalMnyMonth; // 单位缴费金额
    private BigDecimal personTotalMnyMonth; // 个人缴费金额
    private BigDecimal totalMnyMonth; // 月费用合计
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date billDate; // 生成日期
    private String upDown; // 当月增减情况0正常1:增2减
    private String upDownName; // 当月增减情况0正常1:增2减
    private Long insuranceId; // 保险缴纳申请单id

    public String getUpDownName() {
        return upDownName;
    }

    public void setUpDownName(String upDownName) {
        this.upDownName = upDownName;
    }

    public Long getInsuranceId() {
        return insuranceId;
    }

    public void setInsuranceId(Long insuranceId) {
        this.insuranceId = insuranceId;
    }


    public String getHumanType() {
        return humanType;
    }

    public void setHumanType(String humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public String getPersonName() {
        return personName;
    }

    public void setPersonName(String personName) {
        this.personName = personName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getInsuredType() {
        return insuredType;
    }

    public void setInsuredType(String insuredType) {
        this.insuredType = insuredType;
    }
    public String getInsuredTypeName() {
        return insuredTypeName;
    }

    public void setInsuredTypeName(String insuredTypeName) {
        this.insuredTypeName = insuredTypeName;
    }
    public String getFeesBorne() {
        return feesBorne;
    }

    public void setFeesBorne(String feesBorne) {
        this.feesBorne = feesBorne;
    }
    public String getFeesBorneName() {
        return feesBorneName;
    }

    public void setFeesBorneName(String feesBorneName) {
        this.feesBorneName = feesBorneName;
    }
    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }
    public String getMonth() {
        return month;
    }

    public void setMonth(String month) {
        this.month = month;
    }
    public BigDecimal getCompanyTotalMnyMonth() {
        return companyTotalMnyMonth;
    }

    public void setCompanyTotalMnyMonth(BigDecimal companyTotalMnyMonth) {
        this.companyTotalMnyMonth = companyTotalMnyMonth;
    }
    public BigDecimal getPersonTotalMnyMonth() {
        return personTotalMnyMonth;
    }

    public void setPersonTotalMnyMonth(BigDecimal personTotalMnyMonth) {
        this.personTotalMnyMonth = personTotalMnyMonth;
    }
    public BigDecimal getTotalMnyMonth() {
        return totalMnyMonth;
    }

    public void setTotalMnyMonth(BigDecimal totalMnyMonth) {
        this.totalMnyMonth = totalMnyMonth;
    }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public String getUpDown() {
        return upDown;
    }

    public void setUpDown(String upDown) {
        this.upDown = upDown;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20250811.061333-275-sources.jar: com/ejianc/business/oa/vo/MonInsuranceVO.java <==
package com.ejianc.business.oa.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 月度保险明细
 * 
 * @author generator
 * 
 */
public class MonInsuranceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String humanType; // 人员类别
    private String humanTypeName; // 人员类别
    private Long personId; // 姓名
    private String personName; // 姓名
    private Long deptId; // 部门
    private String deptName; // 部门
    private String insuredType; // 保险种类
    private String insuredTypeName; // 保险种类
    private String feesBorne; // 费用承担情况
    private String feesBorneName; // 费用承担情况
    private String year; // 年份
    private String month; // 月度
    private BigDecimal companyTotalMnyMonth; // 单位缴费金额
    private BigDecimal personTotalMnyMonth; // 个人缴费金额
    private BigDecimal totalMnyMonth; // 月费用合计
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date billDate; // 生成日期
    private String upDown; // 当月增减情况0正常1:增2减
    private String upDownName; // 当月增减情况0正常1:增2减
    private Long insuranceId; // 保险缴纳申请单id
    private Long orgId; // 组织
    private String orgName; // 组织

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getUpDownName() {
        return upDownName;
    }

    public void setUpDownName(String upDownName) {
        this.upDownName = upDownName;
    }

    public Long getInsuranceId() {
        return insuranceId;
    }

    public void setInsuranceId(Long insuranceId) {
        this.insuranceId = insuranceId;
    }


    public String getHumanType() {
        return humanType;
    }

    public void setHumanType(String humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public String getPersonName() {
        return personName;
    }

    public void setPersonName(String personName) {
        this.personName = personName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getInsuredType() {
        return insuredType;
    }

    public void setInsuredType(String insuredType) {
        this.insuredType = insuredType;
    }
    public String getInsuredTypeName() {
        return insuredTypeName;
    }

    public void setInsuredTypeName(String insuredTypeName) {
        this.insuredTypeName = insuredTypeName;
    }
    public String getFeesBorne() {
        return feesBorne;
    }

    public void setFeesBorne(String feesBorne) {
        this.feesBorne = feesBorne;
    }
    public String getFeesBorneName() {
        return feesBorneName;
    }

    public void setFeesBorneName(String feesBorneName) {
        this.feesBorneName = feesBorneName;
    }
    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }
    public String getMonth() {
        return month;
    }

    public void setMonth(String month) {
        this.month = month;
    }
    public BigDecimal getCompanyTotalMnyMonth() {
        return companyTotalMnyMonth;
    }

    public void setCompanyTotalMnyMonth(BigDecimal companyTotalMnyMonth) {
        this.companyTotalMnyMonth = companyTotalMnyMonth;
    }
    public BigDecimal getPersonTotalMnyMonth() {
        return personTotalMnyMonth;
    }

    public void setPersonTotalMnyMonth(BigDecimal personTotalMnyMonth) {
        this.personTotalMnyMonth = personTotalMnyMonth;
    }
    public BigDecimal getTotalMnyMonth() {
        return totalMnyMonth;
    }

    public void setTotalMnyMonth(BigDecimal totalMnyMonth) {
        this.totalMnyMonth = totalMnyMonth;
    }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public String getUpDown() {
        return upDown;
    }

    public void setUpDown(String upDown) {
        this.upDown = upDown;
    }
    
}
